use once_cell::sync::OnceCell;
use sqlx::{Pool, Postgres};
use sqlx::postgres::PgPoolOptions;

pub static POSTGRES_POOL: OnceCell<Pool<Postgres>> = OnceCell::new();

pub fn init_db_pool() {
    if let Some(pg) = &crate::boot::global().postgres {
        let pool = PgPoolOptions::new()
            .min_connections(pg.min)
            .max_connections(pg.max)
            .connect_lazy(&pg.dsn).unwrap();
        assert!(POSTGRES_POOL.set(pool).is_ok());
        println!("datasource: {}\n       min: {}\n       max: {}", pg.dsn, pg.min, pg.max)
    }
}

#[allow(dead_code)]
pub fn get_pool() -> Option<&'static Pool<Postgres>> {
    POSTGRES_POOL.get()
}
